@@ -35,20 +35,17 @@ def kl_divergence(X, Y):
     return np.asarray(D)
 
 
-def intersect(a, b): 
+def intersect(lst1, lst2): 
     """
-    param: a - list
-    param: b - list
+    param: lst1 - list
+    param: lst2 - list
     
     return: list of common elements
     """
-    a_set = set(a) 
-    b_set = set(b) 
-    if (a_set & b_set): 
-        return list(a_set & b_set) 
-    else: 
-        print("No common elements")
-        
+
+    temp = set(lst2)
+    lst3 = [value for value in lst1 if value in temp]
+    return lst3 
 
 def norm_and_center_coordinates(X): 
     """
@@ -77,4 +74,6 @@ def match_spots_using_spatial_heuristic(X,Y,use_ot=True):
         pi[row_ind, col_ind] = 1/max(n1,n2)
         if n1<n2: pi[:, [(j not in col_ind) for j in range(n2)]] = 1/(n1*n2)
         elif n2<n1: pi[[(i not in row_ind) for i in range(n1)], :] = 1/(n1*n2)
-    return pi
\ No newline at end of file
+    return pi
+
+to_dense_array = lambda X: np.array(X.todense()) if isinstance(X,scipy.sparse.csr.spmatrix) else X
\ No newline at end of file
